referrerpolicy=no-referrer-when-downgrade

BeefySignerAuthority

Trait BeefySignerAuthority 

pub trait BeefySignerAuthority: AppPair {
    // Required method
    fn sign(&self, message: &[u8]) -> <Self as AppCrypto>::Signature;
}
Trait representing BEEFY specific generation and signing behavior of authority id.

The trait mimics BeefyAuthorityId signing, but uses the private key instead of a keystore. This is needed for testing purposes.

Required Methods

fn sign(&self, message: &[u8]) -> <Self as AppCrypto>::Signature

Generate and return signature for message.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl BeefySignerAuthority for <AuthorityId as AppCrypto>::Pair

Available on crate feature bls-experimental only.
Source

impl BeefySignerAuthority for <AuthorityId as AppCrypto>::Pair